/* Developed for Lenovo Educational Board Pass 2
   © Lenovo Created by Joshua Grosser
   v. 1.0 */

// define global variables and pins
#define BUZZER 15
#define Button1 1
#define Button2 2
int elapsedMillis = 0;
int currentMillis = 0;
int startMillis = 0;
int h = 0; int m = 0; int s = 0;

void setup() {
  // set baud rate
  Serial.begin(9600);
  // set the appropriate state for buzzer and buttons
  pinMode(BUZZER, OUTPUT);
  pinMode(Button1, INPUT);
  pinMode(Button2, INPUT);
  Serial.println();
  Serial.println();
  Serial.println("Please decide whether your want to use the timer or the stopwatch.");
  Serial.println("Type 't' for timer or 's' for stopwatch.");  
}

void loop() {
  while(Serial.available() > 0)
  {
    char type = Serial.read(); // reads input from serial
    h = 0; m = 0; s = 0;
    // A newline character indicates end of input
    if(Serial.read() == '\n')
    {
      if (type == 's') // if input is s for stopwatch
      {
        Serial.println("You chose stopwatch.");
        startMillis = millis();
        while(digitalRead(Button2) == LOW) // loops while button 2 is not pushed
        {
          currentMillis = millis();
          elapsedMillis = (currentMillis - startMillis);
          // calculates h,m,s then prints it
          h = (elapsedMillis / 3600000);
          m = ((elapsedMillis -(h*360000)) / 60000);
          s = ((elapsedMillis - ((m*60000)+(h*3600000))) / 1000);
          Serial.print(h);
          Serial.print(" hr ");
          Serial.print(m);
          Serial.print(" min ");
          Serial.print(s);
          Serial.print(" sec ");
          Serial.print(elapsedMillis - ((s*1000)+(m*60000)+(h*3600000)));
          Serial.println(" ms");
          if (digitalRead(Button1) == HIGH) // resets stopwatch from zero
          {
            startMillis = millis();
          }
        }
        Serial.println();
        Serial.println();
        Serial.println("Please decide whether your want to use the timer or the stopwatch.");
        Serial.println("Type 't' for timer or 's' for stopwatch.");
      }
      else if (type == 't') // if input is t for timer
      {
        Serial.println("You chose timer.");
        Serial.println();
        Serial.println();
        Serial.println("Please enter the number of hours, minutes, and seconds for the timer.");
        Serial.println("hours,minutes,seconds");
        Serial.println("ex: 0,5,5");
        Serial.println("This would start a timer for 5 minutes and 5 seconds");
        while(digitalRead(Button2) == LOW) // loops while button 2 is not pushed
        {
          while(Serial.available() > 0)
          {
            // reads input from serial into integers
            int hour = Serial.parseInt(); 
            int minute = Serial.parseInt();
            int second = Serial.parseInt();
            // A newline character indicates end of input
            if(Serial.read() == '\n')
            {
              // Adjust the values if out of range
              hour = constrain(hour, 0, 23);
              minute = constrain(minute, 0, 59);
              second = constrain(second, 0, 59);
              Serial.print("Setting the timer with");
              Serial.print(" hours=");
              Serial.print(hour, DEC);
              Serial.print(" minutes=");
              Serial.print(minute, DEC);
              Serial.print(" seconds=");
              Serial.println(second, DEC);
              int totalTime = (hour*3600000) + (minute*60000) + (second*1000);
              int curTime = millis();
              int finalTime = totalTime + curTime;
              int remainingTime = 0;
              while(finalTime >= curTime) // counts backwards by subtracting the curTime from totalTime
              {
                curTime = millis();
                remainingTime = finalTime - curTime;
                h = (remainingTime / 3600000);
                m = ((remainingTime -(h*3600000)) / 60000);
                s = ((remainingTime - ((m*60000)+(h*3600000))) / 1000);
                Serial.print(h);
                Serial.print(" hr ");
                Serial.print(m);
                Serial.print(" min ");
                Serial.print(s);
                Serial.println(" sec");
              }
              myTone(BUZZER, 500, 2000); // plays buzzer sound when timer is complete
              Serial.println();
              Serial.println();
              Serial.println("Please enter the number of hours, minutes, and seconds for the timer.");
              Serial.println("hours,minutes,seconds");
              Serial.println("ex: 0,5,5");
              Serial.println("This would start a timer for 5 minutes and 5 seconds");
            }
          }
        }
        Serial.println();
        Serial.println();
        Serial.println("Please decide whether your want to use the timer or the stopwatch.");
        Serial.println("Type 't' for timer or 's' for stopwatch.");
      }
      else // if input is not t or s
      {
        Serial.println("Not a valid input. Type either 't' or 's' to continue.");
      }
    }
  }
}

void myTone(byte pin, uint16_t frequency, uint16_t duration) 
{ // input parameters: Arduino pin number, frequency in Hz, duration in milliseconds
  // plays the tone we want by using the vibrations of the buzzer
  unsigned long startTime=millis();
  unsigned long halfPeriod= 1000000L/frequency/2;
  while (millis()-startTime< duration)
  {
    digitalWrite(pin,HIGH);
    delayMicroseconds(halfPeriod);
    digitalWrite(pin,LOW);
    delayMicroseconds(halfPeriod);
  }
}
