/* Developed for Lenovo Educational Board Pass 2
   © Lenovo Created by Joshua Grosser
   v. 1.0 */

#include <Wire.h>   // I2C library
#include "ens210.h" // ENS210 library
#include <Adafruit_NeoPixel.h> // Neopixel library

#define NEOPIXEL_PIN 45  // Neopixel is on pin 45
#define NEOPIXEL_COUNT  1  // There is only 1 RGB LED on Dos.
#define NEOPIXEL_INDEX  0  // RGB LED is at index 0.
#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels
float CurTemp; // store current temperature

Adafruit_NeoPixel Pixel(NEOPIXEL_COUNT, NEOPIXEL_PIN, NEO_GRB + NEO_KHZ800);
ENS210 ens210;

void setup() {
  // set the baud rate on the serial port
  Serial.begin(115200);
  
  // initialize the Neopixel object
  Pixel.begin();
  // set all pixel colors to OFF
  Pixel.clear();
  Pixel.show();

  // initialize I2C
  Wire.begin();
  // Enable ENS210
  ens210.begin();
}

void loop() {
  // resets Neopixel color
  Pixel.setPixelColor(NEOPIXEL_INDEX, 0, 0, 0);
  // reads temperature data to CurTemp variable
  int t_data, t_status, h_data, h_status;
  ens210.measure(&t_data, &t_status, &h_data, &h_status);
  CurTemp = ens210.toFahrenheit(t_data, 10) / 10.0;
  Serial.print("Temp: ");
  Serial.print( CurTemp );
  Serial.print(" F");
  Serial.println();
  // temperatures are associated with a color
  if (CurTemp <= 35.0) // set to blue
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 0, 0, 255);
  }
  else if (CurTemp > 35.0 && CurTemp <= 50.0) // set to light blue
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 30, 30, 255);
  }
  else if (CurTemp > 50.0 && CurTemp <= 60.0) // set to green
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 0, 255, 0);
  }
  else if (CurTemp > 60.0 && CurTemp <= 70.0) // set to yellow
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 255, 255, 0);
  }
  else if (CurTemp > 70.0 && CurTemp <= 80.0) // set to orange
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 140, 30, 0);
  }
  else if (CurTemp > 80.0 && CurTemp <= 90.0) // set to red
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 255, 15, 10);
  }
  else if (CurTemp > 90.0 && CurTemp <= 100.0) // set to pink red
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 255, 50, 50);
  }
  else if (CurTemp > 100.0) // set to white
  {
    Pixel.setPixelColor(NEOPIXEL_INDEX, 255, 255, 255);
  }
  // push the color to the neopixel
  Pixel.show();
  // waits 5 seconds
  delay(5000);
}
